@@ -1,18 +1,5 @@
-__all__ = (
-        'ConnectionLostError',
-        'Error',
-        'ErrorReply',
-        'NoAvailableConnectionsInPoolError',
-        'NoRunningScriptError',
-        'NotConnectedError',
-        'ScriptKilledError',
-        'TimeoutError',
-        'TransactionError',
-)
-
-
 # See following link for the proper way to create user defined exceptions:
-# http://docs.python.org/3.3/tutorial/errors.html#user-defined-exceptions
+# http://docs.python.org/3.8/tutorial/errors.html#user-defined-exceptions
 
 
 class Error(Exception):
@@ -29,7 +16,8 @@ class TransactionError(Error):
 
 class NotConnectedError(Error):
     """ Protocol is not connected. """
-    def __init__(self, message='Not connected'):
+
+    def __init__(self, message="Not connected"):
         super().__init__(message)
 
 
@@ -42,6 +30,7 @@ class ConnectionLostError(NotConnectedError):
     Connection lost during query.
     (Special case of ``NotConnectedError``.)
     """
+
     def __init__(self, exc):
         self.exception = exc
 
@@ -51,6 +40,7 @@ class NoAvailableConnectionsInPoolError(NotConnectedError):
     When the connection pool has no available connections.
     """
 
+
 class ScriptKilledError(Error):
     """ Script was killed during an evalsha call. """
 
