@@ -1,16 +1,15 @@
 import asyncio
-from asyncio.tasks import gather
 
 __all__ = (
-    'BlockingPopReply',
-    'DictReply',
-    'ListReply',
-    'PubSubReply',
-    'SetReply',
-    'StatusReply',
-    'ZRangeReply',
-    'ConfigPairReply',
-    'InfoReply',
+    "BlockingPopReply",
+    "DictReply",
+    "ListReply",
+    "PubSubReply",
+    "SetReply",
+    "StatusReply",
+    "ZRangeReply",
+    "ConfigPairReply",
+    "InfoReply",
 )
 
 
@@ -19,11 +18,12 @@ class StatusReply:
     Wrapper for Redis status replies.
     (for messages like OK, QUEUED, etc...)
     """
+
     def __init__(self, status):
         self.status = status
 
     def __repr__(self):
-        return 'StatusReply(status=%r)' % self.status
+        return f"StatusReply(status={self.status!r})"
 
     def __eq__(self, other):
         return self.status == other.status
@@ -40,9 +40,10 @@ class DictReply:
     ::
 
         for f in dict_reply:
-            key, value = yield from f
+            key, value = await f
             print(key, value)
     """
+
     def __init__(self, multibulk_reply):
         self._result = multibulk_reply
 
@@ -50,36 +51,36 @@ class DictReply:
         return key, value
 
     def __iter__(self):
-        """ Yield a list of futures that yield { key: value } tuples. """
-        i = iter(self._result)
+        """Yield a list of futures that yield { key: value } tuples
+        """
 
-        @asyncio.coroutine
-        def getter(f):
-            """ Coroutine which processes one item. """
-            key, value = yield from f
+        async def getter(f):
+            """Coroutine which processes one item
+            """
+            key, value = await f
             key, value = self._parse(key, value)
             return key, value
 
         for _ in range(self._result.count // 2):
             read_future = self._result._read(count=2)
-            yield asyncio.async(getter(read_future), loop=self._result._loop)
+            yield asyncio.ensure_future(getter(read_future))
 
-    @asyncio.coroutine
-    def asdict(self):
+    async def asdict(self):
         """
         Return the result as a Python dictionary.
         """
-        data = yield from self._result._read(count=self._result.count)
+        data = await self._result._read(count=self._result.count)
         return dict(self._parse(k, v) for k, v in zip(data[::2], data[1::2]))
 
     def __repr__(self):
-        return '%s(length=%r)' % (self.__class__.__name__, int(self._result.count / 2))
+        return f"{self.__class__.__name__}(length={self._result.count // 2})"
 
 
 class ZRangeReply(DictReply):
     """
     Container for a zrange query result.
     """
+
     def _parse(self, key, value):
         # Mapping { key: score_as_float }
         return key, float(value)
@@ -94,9 +95,10 @@ class SetReply:
     ::
 
         for f in set_reply:
-            item = yield from f
+            item = await f
             print(item)
     """
+
     def __init__(self, multibulk_reply):
         self._result = multibulk_reply
 
@@ -104,14 +106,13 @@ class SetReply:
         """ Yield a list of futures. """
         return iter(self._result)
 
-    @asyncio.coroutine
-    def asset(self):
+    async def asset(self):
         """ Return the result as a Python ``set``.  """
-        data = yield from self._result._read(count=self._result.count)
+        data = await self._result._read(count=self._result.count)
         return set(data)
 
     def __repr__(self):
-        return 'SetReply(length=%r)' % (self._result.count)
+        return f"SetReply(length={self._result.count})"
 
 
 class ListReply:
@@ -124,9 +125,10 @@ class ListReply:
     ::
 
         for f in list_reply:
-            item = yield from f
+            item = await f
             print(item)
     """
+
     def __init__(self, multibulk_reply):
         self._result = multibulk_reply
 
@@ -134,14 +136,12 @@ class ListReply:
         """ Yield a list of futures. """
         return iter(self._result)
 
-    @asyncio.coroutine
     def aslist(self):
-        """ Return the result as a Python ``list``. """
-        data = yield from self._result._read(count=self._result.count)
-        return data
+        """ Return a coroutine with the result as a Python ``list``. """
+        return self._result._read(count=self._result.count)
 
     def __repr__(self):
-        return 'ListReply(length=%r)' % (self._result.count, )
+        return f"ListReply(length={self._result.count})"
 
 
 class BlockingPopReply:
@@ -149,6 +149,7 @@ class BlockingPopReply:
     :func:`~asyncio_redis.RedisProtocol.blpop` or
     :func:`~asyncio_redis.RedisProtocol.brpop` reply
     """
+
     def __init__(self, list_name, value):
         self._list_name = list_name
         self._value = value
@@ -164,11 +165,12 @@ class BlockingPopReply:
         return self._value
 
     def __repr__(self):
-        return 'BlockingPopReply(list_name=%r, value=%r)' % (self.list_name, self.value)
+        return f"BlockingPopReply(list_name={self.list_name!r}, value={self.value!r})"
 
 
 class ConfigPairReply:
     """ :func:`~asyncio_redis.RedisProtocol.config_get` reply. """
+
     def __init__(self, parameter, value):
         self._paramater = parameter
         self._value = value
@@ -184,23 +186,26 @@ class ConfigPairReply:
         return self._value
 
     def __repr__(self):
-        return 'ConfigPairReply(parameter=%r, value=%r)' % (self.parameter, self.value)
+        return f"ConfigPairReply(parameter={self.parameter!r}, value={self.value!r})"
 
 
 class InfoReply:
     """ :func:`~asyncio_redis.RedisProtocol.info` reply. """
+
     def __init__(self, data):
-        self._data = data # TODO: implement parser logic
+        self._data = data  # TODO: implement parser logic
 
 
 class ClientListReply:
     """ :func:`~asyncio_redis.RedisProtocol.client_list` reply. """
+
     def __init__(self, data):
-        self._data = data # TODO: implement parser logic
+        self._data = data  # TODO: implement parser logic
 
 
 class PubSubReply:
     """ Received pubsub message. """
+
     def __init__(self, channel, value, *, pattern=None):
         self._channel = channel
         self._value = value
@@ -222,12 +227,14 @@ class PubSubReply:
         return self._pattern
 
     def __repr__(self):
-        return 'PubSubReply(channel=%r, value=%r)' % (self.channel, self.value)
+        return f"PubSubReply(channel={self.channel!r}, value={self.value!r})"
 
     def __eq__(self, other):
-        return (self._channel == other._channel and
-                self._value == other._value and
-                self._pattern == other._pattern)
+        return (
+            self._channel == other._channel
+            and self._value == other._value
+            and self._pattern == other._pattern
+        )
 
 
 class EvalScriptReply:
@@ -237,11 +244,11 @@ class EvalScriptReply:
     Lua scripts can return strings/bytes (NativeType), but also ints, lists or
     even nested data structures.
     """
+
     def __init__(self, protocol, value):
         self._protocol = protocol
         self._value = value
 
-    @asyncio.coroutine
     def return_value(self):
         """
         Coroutine that returns a Python representation of the script's return
@@ -249,8 +256,7 @@ class EvalScriptReply:
         """
         from asyncio_redis.protocol import MultiBulkReply
 
-        @asyncio.coroutine
-        def decode(obj):
+        async def decode(obj):
             if isinstance(obj, int):
                 return obj
 
@@ -259,15 +265,10 @@ class EvalScriptReply:
 
             elif isinstance(obj, MultiBulkReply):
                 # Unpack MultiBulkReply recursively as Python list.
-                result = []
-                for f in obj:
-                    item = yield from f
-                    result.append((yield from decode(item)))
-                return result
+                return [(await decode(await f)) for f in obj]
 
             else:
                 # Nonetype, or decoded bytes.
                 return obj
 
-        return (yield from decode(self._value))
-
+        return decode(self._value)
